#
# spec file for package graylog
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?suse_version} > 1140 || 0%{?fedora_version} > 14
%define has_systemd 1
%else
%define has_systemd 0
%endif

%define gl_home %{_prefix}/lib/graylog
%{!?_initddir: %{expand: %%global _initddir %{_initrddir}}}
%{!?_rundir: %{expand: %%global _rundir %{_localstatedir}/run}}

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           graylog
Version:        3.3.16
Release:        1.1

Summary:        Field-tested open source data analytics system for logs
License:        GPL-3.0+
Group:          Productivity/Networking/Web/Frontends

Url:            https://www.graylog.org
Source0:        https://downloads.graylog.org/releases/%{name}/%{name}-%{version}.tgz
Source1:        init.d-%{name}
Source2:        sysconfig.%{name}
Source3:        log4j.xml
Source4:        service.graylog
Source5:        tmpfiles.conf-graylog
Source6:        init.d-graylog-suse
Source7:        graylog.logrotate
NoSource:       0
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       java-openjdk >= 1.8.0
Requires:       jpackage-utils
Requires:       logrotate
PreReq:         /bin/echo /bin/mkdir /usr/bin/touch
PreReq:         %fillup_prereq
PreReq:         fillup
Provides:       graylog2-server

# so we do not need to own tmpfiles.d...
%if 0%{?has_systemd}
BuildRequires:  systemd
%{?systemd_requires}
%endif
%if 0%{?suse_version}
Requires(pre):  shadow
Requires(pre):  util-linux
%else
Requires(post): chkconfig
Requires(post): initscripts
Requires(pre):  chkconfig
Requires(pre):  initscripts
Requires(pre):  shadow-utils
%endif

%description
Manage billions of events and process hundreds of thousands of new events every second.
All of the infrastructure runs in your own data center: No need to worry about
sensitive data leaving your company or shipping your logs away over the internet.
Graylog is leveraging proven technologies e.g. Java, Scala and ElasticSearch.
All communication is done via REST APIs so you can even build your
own tools on top of it. The graylog package ships with an interactive API browser.

%if 0%{?suse_version} > 1110
# SLE11 does not like empty packages

%package mongodb
Summary:        Graylog MongoDB Prerequisite
Group:          Productivity/Databases/Tools
Requires:       %{name} = %{version}
Requires:       mongodb >= 2.4

%description mongodb
This package provides the MongoDB requirement for the Graylog Architecture.

http://docs.graylog.org/en/latest/pages/architecture.html

%package elasticsearch 
Summary:        Graylog Elasticsearch Prerequisite
Requires:       %{name} = %{version}
Requires:       elasticsearch < 7
Group:          Productivity/Databases/Tools

%description elasticsearch
This package provides the Elasticsearch for the Graylog Architecture.

http://docs.graylog.org/en/latest/pages/architecture.html
%endif

%prep
%setup -q

%build
sed -ri 's@^(node_id_file.=).*@\1 %{_sysconfdir}/graylog/server-node-id@g' graylog.conf.example
sed -ri 's@(rules_file.=).*@\1 %{_sysconfdir}/graylog/server.drl@g' graylog.conf.example
sed -ri 's@(message_journal_dir.=).*@\1 %{_localstatedir}/spool/graylog@g' graylog.conf.example

%install
# sles is a bit nagging about version of bytecode so lets make it quiet :)
export NO_BRP_CHECK_BYTECODE_VERSION=true

%{__mkdir} -p %{buildroot}%{_fillupdir}
%{__mkdir} -p %{buildroot}%{gl_home}/server/bin
%{__install} -p -m 755 graylog.jar %{buildroot}%{gl_home}/server/
%{__install} -p -m 755 bin/graylogctl %{buildroot}%{gl_home}/server/bin/
# config
%{__mkdir} -p %{buildroot}%{_sysconfdir}/graylog
# create file for ghosting...
touch %{buildroot}%{_sysconfdir}/graylog/server-node-id
%{__install} -m 644 graylog.conf.example %{buildroot}%{_sysconfdir}/graylog/server.conf
%{__install} -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/graylog/server-log4j.xml

# logs
%{__mkdir} -p %{buildroot}%{_localstatedir}/log/graylog

# plugins
%{__mkdir} -p %{buildroot}%{gl_home}/server/plugin/alarm_callbacks
%{__mkdir} -p %{buildroot}%{gl_home}/server/plugin/filters
%{__mkdir} -p %{buildroot}%{gl_home}/server/plugin/initializers
%{__mkdir} -p %{buildroot}%{gl_home}/server/plugin/inputs
%{__mkdir} -p %{buildroot}%{gl_home}/server/plugin/ouput
%{__mkdir} -p %{buildroot}%{gl_home}/server/plugin/transports

# sysconfig and init
%{__mkdir} -p %{buildroot}%{_sysconfdir}/sysconfig
%{__mkdir} -p %{buildroot}%{_initddir}
%if 0%{?suse_version}
 %if 0%{?suse_version} <= 1210
 %{__install} -m 755 %{SOURCE6} %{buildroot}%{_initddir}/%{name}
 %endif
%else
%{__install} -m 755 %{SOURCE1} %{buildroot}%{_initddir}/%{name}
%endif
%{__install} -Dm 644 %{SOURCE2} %{buildroot}%{_fillupdir}/
%{__mkdir} -p %{buildroot}%_sbindir
(cd %{buildroot}%_sbindir ; ln -s %{_initddir}/%{name} rc%{name})
%if 0%{?has_systemd}
%{__mkdir} -p %{buildroot}%_unitdir
%{__install} -Dm 644 %{SOURCE4} %{buildroot}%_unitdir/%{name}.service
%{__install} -Dm 644 %{SOURCE5} %{buildroot}%_tmpfilesdir/%{name}.conf
(cd %{buildroot}%_sbindir && ln -sf /usr/sbin/service rc%{name})
%endif
%{__install} -Dm 644 %{SOURCE7}  %{buildroot}%{_sysconfdir}/logrotate.d/%name

%{__mkdir} -p %{buildroot}%{_rundir}/graylog
%{__mkdir} -p %{buildroot}%{_localstatedir}/spool/graylog

%pre
# create graylog group
if ! getent group graylog >/dev/null; then
        groupadd -r graylog
fi

# create graylog user
if ! getent passwd graylog >/dev/null; then
        useradd -r -g graylog -d %{gl_home} \
            -s /sbin/nologin -c "Party Gorilla" graylog
fi
#
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%endif

%post
%{fillup_and_insserv -n -y %{name}}
%restart_on_update
if [ ! -s %{_sysconfdir}/graylog/server-node-id ]; then
        uuidgen > %{_sysconfdir}/graylog/server-node-id
fi
#
%if 0%{?has_systemd}
systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf
%service_add_post %{name}.service
%endif

%preun
%if 0%{?has_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal
%endif
#

%postun
%if 0%{?has_systemd}
%service_del_postun %{name}.service
%else
%insserv_cleanup
%restart_on_update
%endif
#

%files
%defattr(-,root,root,-)
%doc COPYING README.markdown
%dir %{gl_home}
%dir %{gl_home}/server
%dir %{gl_home}/server/bin
%dir %{gl_home}/server/plugin
%dir %{gl_home}/server/plugin/alarm_callbacks
%dir %{gl_home}/server/plugin/filters
%dir %{gl_home}/server/plugin/initializers
%dir %{gl_home}/server/plugin/inputs
%dir %{gl_home}/server/plugin/ouput
%dir %{gl_home}/server/plugin/transports
%dir %{_sysconfdir}/graylog
%dir %attr(-,graylog,graylog) %{_localstatedir}/spool/graylog
%dir %attr(-,graylog,graylog) %{_localstatedir}/log/graylog
%if 0%{?suse_version} <= 1210
%{_initddir}/graylog
%endif
%config(noreplace) %{_fillupdir}/*
%config(noreplace) %{_sysconfdir}/graylog/server.conf
%config(noreplace) %{_sysconfdir}/graylog/server-log4j.xml
%config(noreplace) %{_sysconfdir}/logrotate.d/%name
%doc README.markdown
%{gl_home}/server/graylog.jar
%{gl_home}/server/bin/graylogctl
%ghost %attr(-,graylog,graylog) %{_rundir}/graylog
%ghost %config(noreplace) %{_sysconfdir}/graylog/server-node-id
%{_sbindir}/rc%{name}
%if 0%{?has_systemd}
%_unitdir/%{name}.service
%_tmpfilesdir/%{name}.conf
%endif

%if 0%{?suse_version} > 1110
%files mongodb

%files elasticsearch
%endif

%changelog
* Mon Dec 20 2021 zombah@gmail.com
- update to 3.3.16
  + Core
  + Security
  * Fix log4j CVE-2021-45046 by updating the library to 2.16.0. Graylog2/graylog2-server#11814
* Fri Dec 10 2021 zombah@gmail.com
- update to 3.3.15
  + Core
  + Security
  * Fix log4j CVE-2021-44228. Graylog2/graylog2-server#11786
* Mon Aug  9 2021 zombah@gmail.com
- update to 3.3.14
  + Core
  + Security
  * Session ID leak in Graylog DEBUG log file and audit log.
    We recently discovered a session ID leak in the Graylog DEBUG log file as well as the audit log. A user can use a session ID to authenticate against Graylog and then this user has access to all the permissions associated with the owner of the session ID.
    The ID was printed in DEBUG level log messages (DEBUG is not enabled by default) as well as the Graylog Enterprise Audit Log. By default, the Graylog Audit Log is only logging to the local database and only accessible by Graylog administrators.
    We would like to thank David Herbstmann for discovering and responsibly disclosing this vulnerability.
    The following CVE IDs have been assigned: CVE-2021-37759, CVE-2021-37760
* Thu Apr 29 2021 zombah@gmail.com
- update to 3.3.12
  + Core
  * Fix rendering of trend colors in report generation. Graylog2/graylog2-server#10157
  * Don’t show “Enterprise” navigation for non-admin users. Graylog2/graylog2-server#8936 Graylog2/graylog2-server#10188 Graylog2/graylog2-server#10233
  * Fix NullPointerException when MongoDB doesn’t run with the MMAPv1 storage engine. Graylog2/graylog2-server#8273 Graylog2/graylog2-server#10300
  * Log failed messages and full stack trace on processing errors when DEBUG is enabled. Graylog2/graylog2-server#10319 Graylog2/graylog2-server#10432
* Fri Mar 12 2021 zombah@gmail.com
- update to 3.3.11
  + Core
  + Fixed
  * Fix search export to dashboard when running with a proxy and a path prefix. Graylog2/graylog2-server#9992 Graylog2/graylog2-server#9989
  * Fix Elasticsearch watermark notifications when running multiple Graylog nodes. Graylog2/graylog2-server#10066
* Mon Feb 15 2021 zombah@gmail.com
- update to 3.3.10
  + Core
  + Added
  * Show field sort icons in message table. Graylog2/graylog2-server#9775
  + Fixed
  * Fix search query parsing with $ characters. Graylog2/graylog2-server#9497 Graylog2/graylog2-server#9877
  * Fix CSV export for shared dashboards. Graylog2/graylog2-server#9906
  * Retry Elasticsearch requests on socket timeouts. Graylog2/graylog2-server#9922
  * Retry bulk indexing if index alias has invalid target(s) instead of dropping the messages. Graylog2/graylog2-server#9955 Graylog2/graylog2-server#9962 Graylog2/graylog2-server#9978
* Wed Dec  9 2020 zombah@gmail.com
- update to 3.3.9
  + Core
  + Fixed
  * Improve user feedback when the UI cannot fetch data from the metrics API. Graylog2/graylog2-server#9315 Graylog2/graylog2-server#9316
  * Updates to Graylog Schema. Graylog2/graylog2-server#9567
* Wed Oct 21 2020 zombah@gmail.com
- update to 3.3.8
  + No changes since 3.3.7
* Fri Oct  9 2020 zombah@gmail.com
- update to 3.3.7
  + Core
  + Security
  * Update JavaScript dependencies with security issues. Graylog2/graylog2-server#9098
  + Fixed
  * Fix issues with changing number of results for a pivot configuration. Graylog2/graylog2-server#9087 Graylog2/graylog2-server#9085
  * Fix permission issue with search and dashboards by respecting ownership. Graylog2/graylog2-server#9068 Graylog2/graylog2-server#9067
  * Fix unintended search bar form submit in widget edit modal. Graylog2/graylog2-server#9096
* Tue Oct  6 2020 zombah@gmail.com
- update to 3.3.6
  https://docs.graylog.org/en/3.3/pages/changelog.html#graylog-3-3-6
* Tue Aug 18 2020 michael@stroeder.com
- update to 3.3.5
  https://docs.graylog.org/en/3.3/pages/changelog.html#graylog-3-3-5
* Thu Aug 13 2020 zombah@gmail.com
- update to 3.3.4
  https://docs.graylog.org/en/3.3/pages/changelog.html#graylog-3-3-4
* Thu Aug 13 2020 zombah@gmail.com
- update to 3.3.3
  + Core
  + Added
  * Add new vendor fields to Graylog schema. Graylog2/graylog2-server#8471 Graylog2/graylog2-server#8642
  + Security
  * [BREAKING]: Enable hostname validation for SSL/TLS-backed LDAP connections. Graylog2/graylog2-server#8625 Prior to v3.3.3, the certificates of LDAP servers which are connected to using a secure connection (SSL or TLS) were not validated, even if the “Allow self-signed certificates” option was unchecked. Starting with v3.3.3, certificates are validated against the local default keystore. This might introduce a breaking change, depending on your local LDAP settings and the validity of the certificates used (if any). Please ensure that all certificates used are valid, their common name matches the host part of your configured LDAP server and your local keystore contains all CA/intermediate certs required for validation.
  * See also: CVE-2020-15813
  + Changed
  * Find a better default for enabled_tls_protocols setting. Graylog2/graylog2-server#7726 Graylog2/graylog2-server#8637 This change builds the default TLS protocols based on what is supported by the currently running JRE.
  + Fixed
  * Fix message table issue in fullscreen/TV mode. Graylog2/graylog2-server#8483 Graylog2/graylog2-server#8575
* Thu Jun 25 2020 zombah@gmail.com
- update to 3.3.2
  + Core
  + Changed
  * Mark legacy aggregation API as deprecated in favor of the new views API. (to be removed in 4.0) Graylog2/graylog2-server#8323
  * Update Graylog field schema. Graylog2/graylog2-server#8331
  * Improve search page rendering performance. Graylog2/graylog2-server#8343
  + Fixed
  * Fix issue with flickering in the single number widget. Graylog2/graylog2-server#7563 Graylog2/graylog2-server#8341
  * Fix issue with extending alert notification grace period. Graylog2/graylog2-server#8365 Graylog2/graylog2-server#8402
  * Fix rendering of message table header. Graylog2/graylog2-server#8415
  + Integrations Plugin
  + Added
  * Add new Palo Alto input to support PAN-OS v9.x devices. Graylog2/graylog-plugin-integrations#496
* Mon Jun 15 2020 zombah@gmail.com
- update to 3.3.1
  + Core
  + Fixed
  * Fix problem with throughput counter in the UI Graylog2/graylog2-server#8172 Graylog2/graylog2-server#8185
  * Fix issue when adding a new header to the HTTPJSONPath lookup data adapter. Graylog2/graylog2-server#8186 Graylog2/graylog2-server#8266
  * Retry message indexing when indices are read-only due to disk space problems in Elasticsearch. Graylog2/graylog2-server#8211 Graylog2/graylog2-server#8269
  * Fix issue with using float numbers in event definitions. Graylog2/graylog2-server#8290
  * Only check data nodes for Elasticsearch disk usage stats. Graylog2/graylog2-server#8239 Graylog2/graylog2-server#8282 (Thanks @radykal-com!)
* Sun May 24 2020 zombah@gmail.com
- update to 3.3.0
  + Core
  + Added
  * Make it possible to create new URL whitelist entries inside forms. Graylog2/graylog2-server#7275 Graylog2/graylog2-server#7169 Graylog2/graylog2-server#7401
  * Store API tokens encrypted in MongoDB. Graylog2/graylog2-server#7556
  * Add new CSV export that supports exporting multiple streams. Graylog2/graylog2-server#7709
  * Add string concatenation to pipeline rule language. Graylog2/graylog2-server#7855 Graylog2/graylog2-server#7863 (Thanks @rmanibus)
  * Add first_non_null pipeline rule function. Graylog2/graylog2-server#7895 Graylog2/graylog2-server#7916 (Thanks @radykal-com)
  * Allow users to request a Graylog Enterprise trial license from inside the product. Graylog2/graylog2-server#7992
  * Add option to enable/disable event definitions and alerts. Graylog2/graylog2-server#7497 Graylog2/graylog2-server#7902
  + Changed
  * Lots of UI styling related changes to make them more consistent.
  * Start index retention from the oldest index, not the newest. Graylog2/graylog2-server#7310
  * Update MongoDB driver to the latest version to support MongoDB 4.2. Graylog2/graylog2-server#7142 Graylog2/graylog2-server#7240 (Thanks @radykal-com)
  * Improve unit tests. Graylog2/graylog2-server#7473 Graylog2/graylog2-server#7595 (Thanks @cpugputpu)
  * Improve progress bar implementation. Graylog2/graylog2-server#7443
  * Don’t directly expose “KafkaJournalConfiguration” values in journal API endpoint. Graylog2/graylog2-server#7521 Graylog2/graylog2-server#7526
  * Optimize JavaScript code bundle sizes. Graylog2/graylog2-server#7598
  * Improve dashboard widget legend positioning. Graylog2/graylog2-server#7743
  * Change default title for dashboard tabs to Page#<num>. Graylog2/graylog2-server#7748
  * Improve triggering search executions from search bar. Graylog2/graylog2-server#7829 Graylog2/graylog2-server#7572 Graylog2/graylog2-server#7596 Graylog2/graylog2-server#7724
  * Don’t truncate messages in process-buffer dump. Graylog2/graylog2-server#7937 Graylog2/graylog2-server#7938
  + Removed
  * Remove unused frontend code from the legacy search. Graylog2/graylog2-server#7338
  * Remove the unused system HTTP client provider. Graylog2/graylog2-server#6376
  * Remove legacy saved searches API endpoints. Graylog2/graylog2-server#7804 Graylog2/graylog2-server#7805
  + Fixed
  * Fix race condition when creating admin role. Graylog2/graylog2-server#7378
  * Display getting started guide with full height. Graylog2/graylog2-server#7529
  * Handle absence of field types in search components. Graylog2/graylog2-server#7538
  * Improve compatibility with IE 11. Graylog2/graylog2-server#7660 Graylog2/graylog2-server#7670 Graylog2/graylog2-server#7951
  * Prevent logging ReadTimeoutException as an error if KeepAlive is configured by the user. Graylog2/graylog2-server#7819 (Thanks @jesseczko)
  * Allow dashboard deletion for users with edit rights. Graylog2/graylog2-server#7729 Graylog2/graylog2-server#7817
  * Only show dashboard delete button for users with correct permissions. Graylog2/graylog2-server#7793 Graylog2/graylog2-server#7846
  * Improve field name completion performance by caching field names. Graylog2/graylog2-server#7827
  * Speed up event processing when it’s lagging behind. Graylog2/graylog2-server#6740
  * Improve performance loading streams from the database. Graylog2/graylog2-server#7867
  * Improve autocompletion performance in select fields. Graylog2/graylog2-server#7753 Graylog2/graylog2-server#7818
  * Improve performance for field type retrieval endpoint. Graylog2/graylog2-server#7865
  * Reset pagination on page size change. Graylog2/graylog2-server#7825 Graylog2/graylog2-server#7826
  * Ensure that dashboards have empty root query strings. Graylog2/graylog2-server#7750 Graylog2/graylog2-server#7858
  * Fix metric naming options in aggregation builder. Graylog2/graylog2-server#7771 Graylog2/graylog2-server#7892
  * Improve tarball packaging. Graylog2/graylog2-server#7920 (Thanks @mayrstefan)
  * Improve error messages when filtering on empty dashboards. Graylog2/graylog2-server#7807 Graylog2/graylog2-server#7888
  * Improve error messages when users don’t have required stream permissions. Graylog2/graylog2-server#7505 Graylog2/graylog2-server#7782
  * Fix LDAP errors for local user accounts. Graylog2/graylog2-server#2267 Graylog2/graylog2-server#7917 (Thanks @mayrstefan)
  * Fix warning in pipeline rule parser. Graylog2/graylog2-server#7918 Graylog2/graylog2-server#7919 (Thanks @mayrstefan)
  * Fix sidebar highlighting layout for field values with a long name. Graylog2/graylog2-server#7738 Graylog2/graylog2-server#8018
  * Improve compatibility with Safari browsers. Graylog2/graylog2-server#8003 Graylog2/graylog2-server#8030
  * Reset job trigger on event definition updates. Graylog2/graylog2-server#7841 Graylog2/graylog2-server#8060
  * Fix problem with event notification grace period. Graylog2/graylog2-server#8065 Graylog2/graylog2-server#8067
  * Improve rendering performance of select fields in event definitions. Graylog2/graylog2-server#8083
  * Improve default email notification template. Graylog2/graylog2-server#8112
  * Fix timezone rendering of event annotations in graphs. Graylog2/graylog2-server#8125
* Tue May 19 2020 zombah@gmail.com
- update to 3.2.5
  + Core
  + Added
  * Add minimal support for Beats 7.x to the beats input. Graylog2/graylog2-server#6501 Graylog2/graylog2-server#7894
  * Show system notification when disk in Elasticsearch fills up. Graylog2/graylog2-server#7899 (Thanks @radykal-com)
  + Changed
  * Enforce unix newlines in the sidecar collector configuration file editor. Graylog2/graylog2-server#7889 Graylog2/collector-sidecar#389 Graylog2/graylog2-server#7975
  * Mask passwords in input configuration returned from the /system/inputstates endpoint. Graylog2/graylog2-server#8037
  * Sanitize URLs in content packs. Graylog2/graylog2-server#8072 Graylog2/graylog2-server#8104
  * Sanitize URls in “Hyperlink String” decorator. Graylog2/graylog2-server#8150
  + Fixed
  * Fix UI issues in sidecar configuration. Graylog2/graylog2-server#7406 Graylog2/graylog2-server#7754
  * Fix dashboard migration issues. Graylog2/graylog2-server#7732 Graylog2/graylog2-server#7749 Graylog2/graylog2-server#7840
  * Fix message list sorting option. Graylog2/graylog2-server#7758 Graylog2/graylog2-server#7763
  * Fix compatibility issue with Safari and the aggregation configuration. Graylog2/graylog2-server#7806 Graylog2/graylog2-server#7815
  * Fix pipeline stage parsing endpoint. Graylog2/graylog2-server#7322 Graylog2/graylog2-server#7830
* Fri Mar 20 2020 zombah@gmail.com
- update to 3.2.4
  + Core
  + Changed
  * Display old LDAP group mappings so they can be deleted by the user. Graylog2/graylog2-server#7502 Graylog2/graylog2-server#7697
  * Don’t allow aggregations on analyzed fields. Graylog2/graylog2-server#7508 Graylog2/graylog2-server#7685
  + Fixed
  * Fix problem with message list pagination. Graylog2/graylog2-server#7680 Graylog2/graylog2-server#7665 Graylog2/graylog2-server#7693
  * Fix issue removing custom fields from event definitions. Graylog2/graylog2-server#7544 Graylog2/graylog2-server#7692
  * Fix drop-down overlay placements on search page. Graylog2/graylog2-server#7723
  * Remove streams parameter from URL when the last stream got removed from a search query. Graylog2/graylog2-server#7717 Graylog2/graylog2-server#7719
* Thu Mar 12 2020 zombah@gmail.com
- update to 3.2.3
  + Core
  + Added
  * Add back auto-completion for _exists_ queries. Graylog2/graylog2-server#7441 Graylog2/graylog2-server#7604
  * Add back surrounding search feature for searches and dashboards. Graylog2/graylog2-server#7616 Graylog2/graylog2-server#7621
  * Add support for newer Kafka versions and allowing more customization options. Graylog2/graylog2-server#7504 (Thanks @muralibasani)
  * Add back field sorting for the message table widget. Graylog2/graylog2-server#7645
  * Add back “replay search” button for dashboard widgets. Graylog2/graylog2-server#7372 Graylog2/graylog2-server#7648
  * Add option to share a saved search with other users. Graylog2/graylog2-server#7668
  + Changed
  * Improve chart rendering for zero values. Graylog2/graylog2-server#7605
  * Rename “Aggregate” field option to “Show top values” to make it more clear. (this was previously called quick values) Graylog2/graylog2-server#7663
  + Fixed
  * Fix widget error “n.find is not a function”. Graylog2/graylog2-server#7365 Graylog2/graylog2-server#7538
  * Fix problem with rendering table widgets. Graylog2/graylog2-server#7565 Graylog2/graylog2-server#7611
  * Fix aggregation event definitions when no streams are selected. Graylog2/graylog2-server#7619 Graylog2/graylog2-server#7625
  * Fix problem with showing message journal statistics on the node details page. Graylog2/graylog2-server#7521 Graylog2/graylog2-server#7633
  * Fix sorting problem when sorting over different streams. Graylog2/graylog2-server#6490 Graylog2/graylog2-server#7569
  * Fix search and dashboard issues with Internet Explorer 11. Graylog2/graylog2-server#7660
  * Fix search page refresh handling. Graylog2/graylog2-server#7661
* Sun Feb 23 2020 zombah@gmail.com
- update to 3.2.2
  + Core
  + Changed
  * Use Graylog data dir for storing netty tcnative libraries. Graylog2/graylog2-server#5762 Graylog2/graylog2-server#7359
  * Add colon (:) when selecting a field from auto-completion. Graylog2/graylog2-server#7408 Graylog2/graylog2-server#7493
  + Fixed
  * Suppress system notification for whitelist errors from test alerts. Graylog2/graylog2-server#7350 Graylog2/graylog2-server#7390
  * Fix issue with duplicating dashboard tabs. Graylog2/graylog2-server#7397
  * Improve search URL synchronization by avoiding unnecessary entries in browser history. Graylog2/graylog2-server#7415
  * Fix error on system overview page. Graylog2/graylog2-server#7329 Graylog2/graylog2-server#7351
  * Fix issue with content pack creation. Graylog2/graylog2-server#6690 Graylog2/graylog2-server#7449
  * Fix problem with dashboard migration and hidden filters. Graylog2/graylog2-server#7366 Graylog2/graylog2-server#7420
  * Fix dashboard migration issue with field name extraction. Graylog2/graylog2-server#7452
  * Fix widget error “n.find is not a function”. Graylog2/graylog2-server#7365 Graylog2/graylog2-server#7450
  * Fix dashboard widget migration error related to value sorting. Graylog2/graylog2-server#7476 Graylog2/graylog2-server#7481
  * Fix issue with Active Directory authentication support. Graylog2/graylog2-server#7431 Graylog2/graylog2-server#7498
  * Fix issue with field ordering in message table widgets. Graylog2/graylog2-server#6808 Graylog2/graylog2-server#7501
  * Fix problem with running Graylog under a subpath. Graylog2/graylog2-server#7447 Graylog2/graylog2-server#7500
  + Integrations Plugin
  + Fixed
  * Fix issue with AWS Kinesis token refresh. Graylog2/graylog-plugin-integrations#386 Graylog2/graylog-plugin-integrations#389
* Sun Feb  9 2020 zombah@gmail.com
- update to 3.2.1
  + Core
  + Fixed
  * Fix problem with message processing and invalid timestamp fields. Graylog2/graylog2-server#7364 Graylog2/graylog2-server#7290
  * Fix scrolling issue in data table widget for Safari browser. Graylog2/graylog2-server#7344 Graylog2/graylog2-server#7353
  * Fix two issues with saved search migration. Graylog2/graylog2-server#7362 Graylog2/graylog2-server#7369
* Sun Feb  2 2020 zombah@gmail.com
- update to 3.2.0
  + Core
  + Added
  * Add configuration options for event index set prefixes. Graylog2/graylog2-server#6340 Graylog2/graylog2-server#6350
  * Add support for trailing comma characters in GELF input. Graylog2/graylog2-server#6325
  * Add “apply” button to pipeline rule editor to improve editing workflow. Graylog2/graylog2-server#6312 Graylog2/graylog2-server#6351 (Thanks @radykal-com!)
  * Start infrastructure for UI theming.
  * Support for percentile aggregations in the aggregation builder. Graylog2/graylog2-server#6597
  * Add support for MaxMind ASN geo IP databases. Graylog2/graylog2-server#6623
  * Introduce cluster global REST API browser button.
  * Add heatmap visualization in aggregation builder. Graylog2/graylog2-server#6678
  * Add area chart visualization to aggregation builder. Graylog2/graylog2-server#6893
  * Add support for disabling the built-in root user. Graylog2/graylog2-server#6688
  * Support for string list values in lookup tables. Graylog2/graylog2-server#6542
  * Add pipeline functions to update string list values in lookup tables. Graylog2/graylog2-server#7189
  * Bring back content pack auto-load. Graylog2/graylog2-server#5744 Graylog2/graylog2-server#6096
  * Add scratchpad for short notes. Graylog2/graylog2-server#6492
  * Add content pack support for searches. Graylog2/graylog2-server#6973
  * Add support for multiple conditions in event and alert aggregations. Graylog2/graylog2-server#6353 Graylog2/graylog2-server#6879
  * Configuration option to enforce system wide TLS protocol settings. Graylog2/graylog2-server#6444 Graylog2/graylog2-server#7130
  * Support for multiple dashboard tabs.
  * Automatic tab rotation on dashboards in TV/full-screen mode.
  * Add gl2_accounted_message_size field to every message to help with accounting license traffic. Graylog2/graylog2-server#6838 Graylog2/graylog2-server#7187
  * Remember event/alert display settings in event/alerts overview page. Graylog2/graylog2-server#6796 Graylog2/graylog2-server#7221
  * Add support for dumping the current process buffer state to help debugging slow processing. Graylog2/graylog2-server#7199
  * Add elasticsearch_discovery_default_scheme config file setting to improve Elasticsearch node discovery. Graylog2/graylog2-server#6280 Graylog2/graylog2-server#6315 (Thanks @radykal-com!)
  * Allow customization of colors in visualizations.
  * Add global filter and timerange override for dashboards. Graylog2/graylog2-server#6424 Graylog2/graylog2-server#6445
  + Changed
  * Improve navigation display on small screens. Graylog2/graylog2-server#6329
  * Introduce abstraction for bootstrap UI components. Graylog2/graylog2-server#6385
  * Improve log level configuration to include more log classes. Graylog2/graylog2-server#6423
  * Improve event notification test button. Graylog2/graylog2-server#6522
  * Don’t show event streams in pipeline configuration. Graylog2/graylog2-server#6454 Graylog2/graylog2-server#6513
  * Migrated legacy dashboards into new dashboards.
  * Migrated legacy saved searches into new search bookmarks.
  * Improve lookup cache error handling. Graylog2/graylog2-server#6295 Graylog2/graylog2-server#6518
  * Migrate “Sources” page into a dashboard. Graylog2/graylog2-server#7024
  + Removed
  * Remove unused search-type implementations. Graylog2/graylog2-server#6438
  * Sources page has been removed and converted into a dashboard. Graylog2/graylog2-server#7024
  + Fixed
  * Fix sorting issue on inputs page. Graylog2/graylog2-server#5921 (Thanks @radykal-com!)
  * Fix issue creating database indices for processin status. Graylog2/graylog2-server#6322 Graylog2/graylog2-server#6333
  * Fix server shutdown problem with message generator input. Graylog2/graylog2-server#6305
  * Fix issue loading views. Graylog2/graylog2-server#6346 Graylog2/graylog2-server#6352
  * Fix display issues with auto-completion in search bar. Graylog2/graylog2-server#6461
  * Fix issue with compound index field types. Graylog2/graylog2-server#6313 Graylog2/graylog2-server#6462
  * Fix issues with field highlighting. Graylog2/graylog2-server#6511 Graylog2/graylog2-server#6512
  * Fix race condition in index management. Graylog2/graylog2-server#6383 Graylog2/graylog2-server#6634
  * Fix issue with event notification backlog seeting display. Graylog2/graylog2-server#6580
  * Fix sorting in streams selection in search. Graylog2/graylog2-server`Graylog2/graylog2-server#6514 <https://github.com/Graylog2/graylog2-server/issues/6514>`_ Graylog2/graylog2-server`Graylog2/graylog2-server#6514 <https://github.com/Graylog2/graylog2-server/issues/6514>`_
  * Fix issue with managing event index set templates. Graylog2/graylog2-server#6507 Graylog2/graylog2-server#6656
  * Fix issue reloading changed GROK patterns in a cluster setup. Graylog2/graylog2-server#6666
  * Fix pipeline rule parsing error. Graylog2/graylog2-server#6716
  * Fix UI problem modifying pipeline stages. Graylog2/graylog2-server#5896 Graylog2/graylog2-server#6743
  * Fix issue with object validation in REST API. Graylog2/graylog2-server#5402
  * Fix timestamp data type issue with COMMONAPACHELOG GROK pattern. Graylog2/graylog2-server#1647 Graylog2/graylog2-server#6847
  * Fix issue with pipelines and the default stream in content packs. Graylog2/graylog2-server#6873 (Thanks @pschichtel!)
  * Improve REST API browser documentation. Graylog2/graylog2-server#6955
  * Fix event aggregation issues with empty fields. Graylog2/graylog2-server#6933 Graylog2/graylog2-server#7070
  * Fix issue with upsert database operations. Graylog2/graylog2-server#7258 Graylog2/graylog2-server#7259
  * Fix issue in DNS adapter that could cause message processing stalls. Graylog2/graylog2-server#5782 Graylog2/graylog2-server#7325
  + Integrations Plugin
  + Added
  * Add IPFIX input plugin.
* Sat Jan 18 2020 zombah@gmail.com
- update to 3.1.4
  + Core
  + Added
  * Add URL whitelist service to make sure that lookup data adapters and event notifications cannot use arbitrary URLs. Attention: The URL whitelist is enabled by default! On the first server startup after the upgrade, the URL whitelist service will automatically generate whitelist entries for existing lookup data adapters and event notifications. See URL whitelist documentation for details.
  + Changed
  * Reduce amount of log messages when job scheduler is disabled on a node. Graylog2/graylog2-server#6451 Graylog2/graylog2-server#6816
  + Fixed
  * Fix global API browser link. Graylog2/graylog2-server#6823 Graylog2/graylog2-server#6826
  * Ensure that aggregation events always have a source_streams field for permission checks. Graylog2/graylog2-server#6876 Graylog2/graylog2-server#6877
  * Fix caching issue with route_to_stream pipeline function. Graylog2/graylog2-server#4954 Graylog2/graylog2-server#6788
  * Fix issue with calculating index ranges. Graylog2/graylog2-server#6828 Graylog2/graylog2-server#6957 Attention: If you are affected by Graylog2/graylog2-server#6828, you have to manually recalculated index ranges for all your index sets.
  * Improve API browser for event resources. Graylog2/graylog2-server#6742 Graylog2/graylog2-server#6955
  * Fix message indexing issue that could potentially stop message indexing completely. Graylog2/graylog2-server#5091 Graylog2/graylog2-server#6965 Graylog2/graylog2-server#7071
  + Integrations Plugin
  + Added
  * Add support for automatic authentication scheme for the AWS Kinesis integration. (environment variables, Java properties, instance roles) Graylog2/graylog-plugin-integrations#264 Graylog2/graylog-plugin-integrations#279
  * Add “assume role” support for AWS Kinesis integration. Graylog2/graylog-plugin-integrations#264 Graylog2/graylog-plugin-integrations#279
  + Fixed
  * Fix rate limit issue with AWS Kinesis streams. Graylog2/graylog-plugin-integrations#341 Graylog2/graylog-plugin-integrations#342
* Thu Nov  7 2019 zombah@gmail.com
- update to 3.1.3
  + Core
  + Added
  * Add test button to allow testing of event notifications. Graylog2/graylog2-server#6138 Graylog2/graylog2-server#6549
  * Add support for MaxMind ASN database type in lookup tables. Graylog2/graylog2-server#6631
  * Add metric_counter_inc pipeline function. Graylog2/graylog2-server#6644
  * Add length pipeline function. Graylog2/graylog2-server#6645
  * Add traffic_accounting_size pipeline function. Graylog2/graylog2-server#6646
  * Implement pipeline rule timers to help debugging slow rules. Graylog2/graylog2-server#5494 Graylog2/graylog2-server#6680
  + Changed
  * Hide event streams from pipelines because events are currently not supported in pipeline rules. Graylog2/graylog2-server#6454 Graylog2/graylog2-server#6545
  * Increase default connection limits for Elasticsearch connections. Graylog2/graylog2-server#4637 Graylog2/graylog2-server#6679
  Fixed
  * Fix problem with message highlighting. Graylog2/graylog2-server#6511 Graylog2/graylog2-server#6526
  * Improve event and alert processing on nodes with low ingest rates. Graylog2/graylog2-server#6453 Graylog2/graylog2-server#6548
  * Remove event streams from global search to fix custom sorting issue. Graylog2/graylog2-server#6384 Graylog2/graylog2-server#6544
  * Fix event processing on nodes with a disabled journal. Graylog2/graylog2-server#6449 Graylog2/graylog2-server#6547
  * Fix UI problem with select components. Graylog2/graylog2-server#6554
  * Fix problem adding multiple percentile aggregations in views. Graylog2/graylog2-server#6597 Graylog2/graylog2-server#6638
  * Fix API browser links in setups with multiple nodes. Graylog2/graylog2-server#2360 Graylog2/graylog2-server#5920 Graylog2/graylog2-server#6636
  * Fix display of backlog size for legacy event notification plugins. Graylog2/graylog2-server#6647
  * Fix issue with MongoDB index creation. Graylog2/graylog2-server#6383 Graylog2/graylog2-server#6643
  * Fix stream permission checks for view searches. Graylog2/graylog2-server#6651
  * Fix stream sorting in streams filter option in views. Graylog2/graylog2-server#6514 Graylog2/graylog2-server#6657
  * Fix problem with event index set migration. Graylog2/graylog2-server#6507 Graylog2/graylog2-server#6662 Graylog2/graylog2-server#6674
  * Ensure Grok pattern reloading on bulk pattern import. Graylog2/graylog2-server#6673
  * Fix error handling in pipeline parser. Graylog2/graylog2-server#6696 Graylog2/graylog2-server#6731
  + Integrations Plugin
  + Fixed
  * Fix checkpointing AWS Kinesis streams. Graylog2/graylog-plugin-integrations#286 Graylog2/graylog-plugin-integrations#294
* Fri Sep 13 2019 zombah@gmail.com
- update to 3.1.2
  + Fixed
  * Cannot read property ‘query’ of undefined when replaying search Graylog2/graylog2-server#6355
  * Cannot focus input fields in modal form (Dashboard) Graylog2/graylog2-server#6356
  * Server start fails with Index with name: compound_0 already exists with a different name Graylog2/graylog2-server#6383
  * Alerting not working if cluster contains nodes with no active inputs Graylog2/graylog2-server#6415
* Mon Sep  9 2019 zombah@gmail.com
- update to 3.1.1
  + Integrations Plugin
  * Add a new AWS Kinesis/CloudWatch Input to Graylog, which guides the user through the setup process and performs checks along the way. It also supports an automated CloudWatch Logs to Kinesis Streams setup which helps to automate much of the complicated manual setup.
  + Fixed
  * Error when loading a view. Graylog2/graylog2-server#6346
  * Fix server startup issue resulting from long index name. Graylog2/graylog2-server#6322
* Wed Aug 21 2019 zombah@gmail.com
- update to 3.1.0
  + Views & Extended Search
  * This feature was partially (everything besides support for parameters in queries) open-sourced in this version.
    Formerly it was accessible only through the commercial enterprise plugin.
  * The API prefix for the views/extended search endpoints has changed from /api/plugins/org.graylog.plugins.enterprise/(views|search) to /api/views & /api/views/search.
  * The configuration file directive specifying the maximum age of an unreferenced search object before it is purged has changed from enterprise_search_maximum_search_age to views_maximum_search_age.
* Tue Jun  4 2019 zombah@gmail.com
- update to 3.0.2
  + Core
  * Fix dashboard position migration. Graylog2/graylog2-server#5737 Graylog2/graylog2-server#5763
  * Fix HTTP 100 handling in http inputs. Graylog2/graylog2-server#5690 Graylog2/graylog2-server#5725
  * Fix http input keep-alive handling. Graylog2/graylog2-server#5720 Graylog2/graylog2-server#5728
  * Fix running Graylog web interface under a path prefix. Graylog2/graylog2-server#5702  Graylog2/graylog2-server#5703
  * Fix issue with wildcards in the search query parser when running with newer Elasticsearch versions. Graylog2/graylog2-server#5719 Graylog2/graylog2-server#5766
  * Fix Grok patterns that use "OR" to not return "null" values. Graylog2/graylog2-server#4773 Graylog2/graylog2-server#5749
  * Fix NetFlow parsing for Cisco ASA devices. Graylog2/graylog2-server#5715 Graylog2/graylog2-server#5729
  * Fix Grok patterns to support underscores in match group names again. Graylog2/graylog2-server#5704 Graylog2/graylog2-server#5563 Graylog2/graylog2-server#5800
  * Document password escaping issue for the MongoDB connection URL. Graylog2/graylog2-server#5680  Graylog2/graylog2-server#5764
  + Threatintel Plugin
  * Fix problem with content pack migration. Graylog2/graylog-plugin-threatintel#123
  + Integrations Plugin
  * Fix issue handling quoted values in PaloAlto input Graylog2/graylog-plugin-integrations#15 Graylog2/graylog-plugin-integrations#16
* Mon Feb 18 2019 zombah@gmail.com
- update to 3.0.0
* Thu Dec 27 2018 zombah@gmail.com
- fix elasticsearch requirement in specfile
* Sat Dec 22 2018 zombah@gmail.com
- update to 2.5.1
  + Core
  * Improve description of web_endpoint_uri in graylog.conf. Contributed by Matt Warren. Graylog2/graylog2-server#5359
  * Add CSRF backward compatibility for older Sidecars. Graylog2/graylog2-server#5388
  * Add custom request header to prevent CSRF. Graylog2/graylog2-server#4987
  + AWS Plugin
  * Remove limit for GZip decompression. Graylog2/graylog-plugin-aws#98
  + Pipeline Plugin
  * Properly handle IPv6 addresses in IPv4 subnet checks. Reported by Moritz Bunkus. Graylog2/graylog2-server#5405Graylog2/graylog-plugin-pipeline-processor#254
* Mon Dec  3 2018 zombah@gmail.com
- update to 2.5.0
  + Core
  * Improve CSRF protection by requiring a custom HTTP header for non-GET requests sent to the API. (requires sidecar 0.1.7) Graylog2/graylog2-server#4998 Graylog2/graylog2-server#5012 Graylog2/graylog2-server#5182
  * Improve alert conditions by making the query string configurable. Graylog2/graylog2-server#5277 Graylog2/graylog2-server#3966
  * Improve alert overview for streams. Graylog2/graylog2-server#5311
  * Add test button for alert conditions. Graylog2/graylog2-server#5322
  * Add DNS lookup adapter that supports foward and reverse lookups. Graylog2/graylog2-server#5274 Graylog2/graylog2-server#4200 Graylog2/graylog2-server#5124 Graylog2/graylog-plugin-threatintel#64
  * Add support for Elasticsearch 6.x. Graylog2/graylog2-server#5020 Graylog2/graylog2-server#5064
  * Update time zone database for the web interface. Graylog2/graylog2-server#5260 Graylog2/graylog2-server#5245
  * Fix description and default values for the DSV HTTP lookup table adapter. Graylog2/graylog2-server#4973 @zionio
  * Fix slow and unreliable CSV export by using a bigger default batch size. Graylog2/graylog2-server#5172 Graylog2/graylog2-server#5304
  * Fix index stats in index set overview. Graylog2/graylog2-server#5306
  * Fix security issue with the users API where regular users could retrieve details of other users. Graylog2/graylog2-server#5308 Graylog2/graylog2-server#5068 @radykal-com
  * Fix backslash escaping for phrase searches. Graylog2/graylog2-server#5314 Graylog2/graylog2-server#4111 Graylog2/graylog2-server#5266
  + AWS Plugin
  * Add throttling support to the AWS Flow Logs input. Graylog2/graylog-plugin-aws#94 Graylog2/graylog-plugin-aws#85
  * Improve logging for the CloudTrail input. Graylog2/graylog-plugin-aws#95 Graylog2/graylog-plugin-aws#80
  + Pipeline Processor Plugin
  * Fix key-value function to be more robust with splitting values. Graylog2/graylog-plugin-pipeline-processor#249 Graylog2/graylog2-server#4920 @radykal-com
  * Add support for decimal IPv4 representation in the to_ip function. Graylog2/graylog-plugin-pipeline-processor#253 Graylog2/graylog2-server#5268
* Thu Jul 19 2018 zombah@gmail.com
- update to 2.4.6
  + Core
  * Unbreak input throttling by publishing throttle state again. Graylog2/graylog2-server#4850Graylog2/graylog2-server#4321
  * Check for permission before terminating input. Graylog2/graylog2-server#4867Graylog2/graylog2-server#4858
  * Require user to be authenticated to retrieve plugin list. Graylog2/graylog2-server#4868Graylog2/graylog2-server#4863
  * Add missing permission checks. Graylog2/graylog2-server#4873 Graylog2/graylog2-server#4861 Graylog2/graylog2-server#4859
  * UI fixes for index rotation strategy dropdown. Graylog2/graylog2-server#4826Graylog2/graylog2-server#4769
  * XSS fix for typeahead components. Graylog2/graylog2-server#4904 (Thanks to Jesper den Boer for finding and responsibly disclosing this vulnerability.)
  * Fix potential NullPointerException in csv and maxmind data adapters. Graylog2/graylog2-server#4912 Graylog2/graylog2-server#4748
  * Add ?http_non_proxy_hosts? configuration option. Graylog2/graylog2-server#4915Graylog2/graylog2-server#4905 Graylog2/graylog2-server#4392
* Fri Jun  1 2018 zombah@gmail.com
- update to 2.4.5
  + Core
  * Improve HTTP proxy authentication to support more proxy server software. Graylog2/graylog2-server#4788 Graylog2/graylog2-server#4790
  * Fix an issue where the Elasticsearch URL credentials have been written to the Graylog log file. Graylog2/graylog2-server#4804 Graylog2/graylog2-server#4806
  * Fix issue with deleting dashboard widgets. Graylog2/graylog2-server#4525 Graylog2/graylog2-server#4808
* Sat May 12 2018 zombah@gmail.com
- update to 2.4.4
  + Core
  * Fix issues with loading example message for extractor. Graylog2/graylog2-server#4553 Graylog2/graylog2-server#4559
  * Allow : character in password. Graylog2/graylog2-server/#4557
  * Fix lookup table cache entry count metric. Graylog2/graylog2-server#4558
  * Simplify plugin development for lookup table plugins. Graylog2/graylog2-server#4586 Graylog2/graylog2-server#4587
  * Fix (XSS) security issue with unescaped text in notification and dashboard names. Graylog2/graylog2-server#4727 Graylog2/graylog2-server#4739
  * Improve high-availability behavior with missing Elasticsearch nodes. Graylog2/graylog2-server#4738
  * Fix issue with updating saved searches. Graylog2/graylog2-server#2285 Graylog2/graylog2-server#4743
  * Fix issue assigning stream outputs to the default stream. Graylog2/graylog2-server#4747 Graylog2/graylog2-server#4754
  * Improve rendering of input configuration forms. Graylog2/graylog2-server#4755 Graylog2/graylog2-server#4745 by @Al2Klimov
  * Add code to allow HTTP proxy authentication in http_proxy_uri config option. Graylog2/graylog2-server#4594 Graylog2/graylog2-server#4758
  + Threatintel Plugin
  * Fix issue with missing threat names in lookup results. Graylog2/graylog-plugin-threatintel#99 by @pbr0ck3r‍
  + AWS Plugin
  * Support new AWS regions. Graylog2/graylog-plugin-aws#71 Graylog2/graylog-plugin-aws#73 Graylog2/graylog-plugin-aws#75
* Wed Jan 31 2018 zombah@gmail.com
- update to 2.4.3
  + Core
  * Fix issue with creating dashboards as non-admin user. Graylog2/graylog2-server#4505 Graylog2/graylog2-server#4511
  * Fix edge case in recent message loader for extractors. Graylog2/graylog2-server#4513 Graylog2/graylog2-server#4510
  * Fix formatting issue when using quick values on the timestamp field. Graylog2/graylog2-server#4423Graylog2/graylog2-server#4288
  * Fix issue with handling the timestamp field in stacked quick value widgets. Graylog2/graylog2-server#4516Graylog2/graylog2-server#4509
  * Fix timezone issue when using the timestamp field in quick values. Graylog2/graylog2-server#4519Graylog2/graylog2-server#4509
  + Threatintel Plugin
  * Fix documentation of the tor_lookup() function. Graylog2/graylog2-server#86
* Wed Jan 31 2018 zombah@gmail.com
- Replace references to /var/adm/fillup-templates with new %%_fillupdir macro
* Tue Jan 16 2018 zombah@gmail.com
- update to 2.4.0
  + Core
  * Fixed node-id validator problem by removing the validator for now. Graylog2/graylog2-server#4433
  * Fix problem with new node-id file check that got introduced in 2.4.0-beta.4. Graylog2/graylog2-server#4428 # 4427
  + Threatintel Plugin
  * Improve Whois data adapter to always use the ARIN registry for now. Graylog2/graylog2-server#78 76
  * Fix object comparison in Whois data adapter. Graylog2/graylog2-server#69
  + Core
  * Improve HTTPJSONPath lookup table data adapter UI. Graylog2/graylog2-server#4406
  * Add and use ExternalLink and ExternalLinkButton components. Graylog2/graylog2-server#4414
  * Improve UI components when user lacks permissions. Graylog2/graylog2-server#4416 Graylog2/graylog2-server#4407
  * Fix output traffic graph on “System/Overview”. Graylog2/graylog2-server#4418 Graylog2/graylog2-server#4395
  * Improve query suggestions for field existence. Graylog2/graylog2-server#4422 Graylog2/graylog2-server#4362
  * Check node-id file permissions and improve error messages. Graylog2/graylog2-server#4417 Graylog2/graylog2-server#4410
  + Pipeline Processor Plugin
  * Fix problem with null values in the select_jsonpath function. Graylog2/graylog-plugin-pipeline-processor#233 Graylog2/graylog-plugin-pipeline-processor#232
  + Threatintel Plugin
  * Fix several issues with OTX and Whois data adapters. Graylog2/graylog-plugin-threatintel#75
  + Anonymous Usage-Stats Plugin
  * The plugin got removed.
  + Core
  * Improve documentation for outputbuffer settings. Graylog2/graylog2-server#4331
  * Improve QuickValues stacking. Graylog2/graylog2-server#4343
  * Improve auth providers UI. Graylog2/graylog2-server#4347
  * Add pluggable global notification area to page. Graylog2/graylog2-server#4353 Graylog2/graylog2-server#4389 Graylog2/graylog2-server#4393
  * Fix changing the default index set from the UI. Graylog2/graylog2-server#4377
  * Add global traffic counter to system overview page. Graylog2/graylog2-server#4357
  * Remove anonymous usage-stats plugin. Graylog2/graylog2-server#4349
  + AWS Plugin
  * Add “logGroup” and “logStream” attributes to flow log and raw log codecs. Graylog2/graylog-plugin-aws#55 Graylog2/graylog-plugin-aws#54
  + CEF Plugin
  * Upgrade to CEF parser 0.0.1.10. Graylog2/graylog-plugin-cef#23 Graylog2/graylog-plugin-cef#24
  + Threatintel Plugin
  * Fix lookup table used in tor_lookup() function. Graylog2/graylog-plugin-threatintel#71
  * Fix lookup table used in spamhaus_lookup_ip() function. Graylog2/graylog-plugin-threatintel#73
  + Core
  * Improve UI elements for field analyzers. Graylog2/graylog2-server#4280 Graylog2/graylog2-server#4230
  * Add upgrade notes for new plugins. Graylog2/graylog2-server#4187
  * Fix query button in QuickValues widget. Graylog2/graylog2-server#4216 Graylog2/graylog2-server#4278
  * Improve QuickValues histogram data. Graylog2/graylog2-server#4312 Graylog2/graylog2-server#4309
  * Add loading indicator when reloading field chart data. Graylog2/graylog2-server#4319
  * Add feedback on create widget modal. Graylog2/graylog2-server#4320 Graylog2/graylog2-server#4318
  * Improve robustness of QuickValues widget with stacked fields. Graylog2/graylog2-server#4322 Graylog2/graylog2-server#4289 Graylog2/graylog2-server#4287 Graylog2/graylog2-server#4082
  * Ship NetFlow plugin by default. Graylog2/graylog2-server#4086
  * Ship AWS plugin by default. Graylog2/graylog2-server#4085
  * Ship Threat Intelligence plugin by default. Graylog2/graylog2-server#4084
  * Ship CEF plugin by default. Graylog2/graylog2-server#4161
  * Fix race condition in user session removal. Graylog2/graylog2-server#4041 Graylog2/graylog2-server#3634 Graylog2/graylog2-server#3948 Graylog2/graylog2-server#3973
  * Update web interface dependencies and fix deprecations. Graylog2/graylog2-server#4057 Graylog2/graylog2-server#4059 Graylog2/graylog2-server#4037 Graylog2/graylog2-server#4192 Graylog2/graylog2-server#4189
  * Improve Elasticsearch query performance. Graylog2/graylog2-server#4056 Graylog2/graylog2-server#4051
  * Improve web UI performance by using React production mode. Graylog2/graylog2-server#4048
  * Add possibility for server plugins to add database migrations. Graylog2/graylog2-server#4095
  * Add support for custom HTTP headers in HTTPJSONPath lookup table adapter. Graylog2/graylog2-server#4094
  * Fix HTTP header size settings. Graylog2/graylog2-server#4128 Graylog2/graylog2-server#4118
  * Add /system/indices/index_sets/{id}/stats REST API endpoint to fetch stats for a single index set. Graylog2/graylog2-server#4129 Graylog2/graylog2-server#4088
  * Add DSV over HTTP data adapter for lookup tables. Graylog2/graylog2-server#4096
  * Improve and update Elasticsearch testing infrastructure. Graylog2/graylog2-server#4125 Graylog2/graylog2-server#4165
  * Improve dashboard widget layout to show long widget titles. Graylog2/graylog2-server#4072 @billmurrin
  * Fix problem in GELF output by removing special handling of the facility. Graylog2/graylog2-server#4141 Graylog2/graylog2-server#4140
  * Expose LdapUserAuthenticator#syncLdapUser() method to allow usage from plugins. Graylog2/graylog2-server#4159 @gaspardpetit
  * Fix problem with getting Elasticsearch stats. Graylog2/graylog2-server#4127 Graylog2/graylog2-server#4119
  * Fix Elasticsearch document counting with lots of indices. Graylog2/graylog2-server#4147 Graylog2/graylog2-server#4136
  * Fix link placement in multi select UI elements. Graylog2/graylog2-server#3911
  * Fix HTTP problems when searching in lots of indices. Graylog2/graylog2-server#4149 Graylog2/graylog2-server#4054 Graylog2/graylog2-server#4168
  * Fix config issues with stacked charts. Graylog2/graylog2-server#4151 Graylog2/graylog2-server#4150
  * Improve eslint rules for UI development. Graylog2/graylog2-server#4173
  * Update serveral server dependencies. Graylog2/graylog2-server#4134
  * Add config option to disable analysis features (such a QuickValues) for certain message fields. Graylog2/graylog2-server#4175 Graylog2/graylog2-server#3957
  * Improve message separator handling for TCP based inputs. Graylog2/graylog2-server#4106 Graylog2/graylog2-server#4105
  * Improve CSV lookup table adapter to use the same field for key and value. Graylog2/graylog2-server#4181 Graylog2/graylog2-server#4177
  * Add possibility to create charts for non-numeric fields to show cardinality and total counts. Graylog2/graylog2-server#4182 Graylog2/graylog2-server#4083
  * Improve widget and grid positioning and styling. Graylog2/graylog2-server#4160 Graylog2/graylog2-server#4209
  * Improve UI testing environment. Graylog2/graylog2-server#4162
  * Improve error logging on indexing failures. Graylog2/graylog2-server#4195 Graylog2/graylog2-server#4166
  * Improve styling for highlighting checkbox in the search sidebar. Graylog2/graylog2-server#4201
  * Fix problem with lookup table content pack import. Graylog2/graylog2-server#4197 Graylog2/graylog-plugin-threatintel#57
  * Add configuration options to QuickValue widget. Graylog2/graylog2-server#4205 Graylog2/graylog2-server#4082 Graylog2/graylog2-server#4259 Graylog2/graylog2-server#4258
  * Improve styling and positioning for search page widget buttons. Graylog2/graylog2-server#4219
  * Improve permission handling to allow regular users to create dashboards. Graylog2/graylog2-server#4155
  * Add stats summary for all index sets to the “System/Indices” page. Graylog2/graylog2-server#4211 Graylog2/graylog2-server#4204
  * Improve table layout in lookup table UI for entries with long descriptions. Graylog2/graylog2-server#4239 Graylog2/graylog2-server#4172
  * Fix permission check which was hiding a menu item in the UI. Graylog2/graylog2-server#4237 Graylog2/graylog2-server#4234
  * Fix error with message histogram selection. Graylog2/graylog2-server#4243 Graylog2/graylog2-server#4214
  * Add histogram option to QuickValue widget to show values over time. Graylog2/graylog2-server#4244 Graylog2/graylog2-server#4082
  * Fix permission handling for editing/deleting roles. Graylog2/graylog2-server#4265
  * Fix some smaller lookup table issues. Graylog2/graylog2-server#4266
  + Map Widget plugin
  * Improve rendering and styling for map widget. Graylog2/graylog-plugin/map-widget#53 Graylog2/graylog-plugin/map-widget#54
  * Improve styling and positioning for search page widget buttons. Graylog2/graylog-plugin/map-widget#56
  + Pipeline Processor plugin
  * Add various Base encoding functions. (e.g. Base16, Base32, Base64) Graylog2/graylog-plugin-pipeline-processor#190
  * Fix sorting of pipeline rules. Graylog2/graylog-plugin-pipeline-processor#208
  * Fix parse_json() function on invalid input. Graylog2/graylog-plugin-pipeline-processor#210 Graylog2/graylog-plugin-pipeline-processor#209
  * Fix NullPointerException when parsing invalid rules. Graylog2/graylog-plugin-pipeline-processor#212 Graylog2/graylog-plugin-pipeline-processor#211
  * Improve documentation for lookup table function. Graylog2/graylog-plugin-pipeline-processor#217 @supahgreg
  * Fix numeric conversions with to_double() and to_long(). Graylog2/graylog-plugin-pipeline-processor#219
  * Improve rule function documentation in editor by sorting functions alphabetically by name. Graylog2/graylog-plugin-pipeline-processor#222
  * Add remove_from_default option to route_to_stream() function. Graylog2/graylog-plugin-pipeline-processor#220
  * Add remove_from_stream() function. Graylog2/graylog-plugin-pipeline-processor#220
  + Collector plugin
  * Add exclude_files configuration option for filebeat collectors. Graylog2/graylog-plugin-collector#63 @silenceper
  + AWS plugin
  * Fix problem with parsing SNS notification messages. Graylog2/graylog-plugin-aws#47 Graylog2/graylog-plugin-aws#44
  * Add support for overriding the source field for all input types. Graylog2/graylog-plugin-aws#46
  * Add support for cross account role based authentication. Graylog2/graylog-plugin-aws#49 Graylog2/graylog-plugin-aws#48 @radykal-com
  + CEF plugin
  * Improve CEF parser and add proper testing infrastructure.
  * Fix problems with Kafka and AMQP inputs.
  + NetFlow plugin
  * Improved NetFlow v9 support. Graylog2/graylog-plugin-netflow#21
  + Threat Intelligence plugin
  * Convert plugin to use the lookup table system. Graylog2/graylog-plugin-threatintel#48
  * Fix problem with absent OTX API key in plugin configuration. Graylog2/graylog-plugin-threatintel#54 Graylog2/graylog-plugin-threatintel#53
  * Improve pipeline function parameter consistency. Graylog2/graylog-plugin-threatintel#58
  * Improve lookup table based data adapters. Graylog2/graylog-plugin-threatintel#63 Graylog2/graylog-plugin-threatintel#61 Graylog2/graylog-plugin-threatintel#59 Graylog2/graylog-plugin-threatintel#67
* Fri Oct 20 2017 zombah@gmail.com
- update to 2.3.2
  + Core
  * Fix permission handling for editing/deleting roles. Graylog2/graylog2-server#4270 Graylog2/graylog2-server#4254
  * Fix CSV export when using lots of Elasticsearch index shards. Graylog2/graylog2-server#4269 Graylog2/graylog2-server#4190
  * Fix infinite redirect loop when accessing non-permitted resources/entities. Graylog2/graylog2-server#4139 Graylog2/graylog2-server#4117
* Thu Sep  7 2017 zombah@gmail.com
- update to 2.3.1
  + Core
  * Fix NullPointerException for field stats. Graylog2/graylog2-server#4026 Graylog2/graylog2-server#4045 Graylog2/graylog2-server#4046
  * Make GELF parser less strict. Graylog2/graylog2-server#4055
  * Fix search requests with selected fields by using source filtering. Graylog2/graylog2-server#4069 Graylog2/graylog2-server#4077 Graylog2/graylog2-server#4068
  * Add missing index for session_id in "sessions" MongoDB collection. Graylog2/graylog2-server#4070 Graylog2/graylog2-server#4076
  * Fix search errors when lots of indices will be used. Graylog2/graylog2-server#4062 Graylog2/graylog2-server#4078 Graylog2/graylog2-server#4054
  * Upgrade to Jest 2.4.7+jackson. Graylog2/graylog2-server#4107
  * Fix search term highlighting. Graylog2/graylog2-server#4108 Graylog2/graylog2-server#4101
  + Pipeline Processor
  * Make locale parameter of parse_date() optional. Graylog2/graylog-plugin-pipeline-processor#202
* Thu Aug 10 2017 zombah@gmail.com
- update to 2.3.0
  + Core
  * Fix remote address field for GELF UDP inputs. Graylog2/graylog2-server#3982 Graylog2/graylog2-server#3988 Graylog2/graylog2-server#3980
  * Improve error messages for rotation strategies. Graylog2/graylog2-server#3995 Graylog2/graylog2-server#3990
  * Fix legend for stacked charts. Graylog2/graylog2-server#4010 Graylog2/graylog2-server#3996
  * Fix size based index rotation strategy. Graylog2/graylog2-server#4011 Graylog2/graylog2-server#4008 Graylog2/graylog2-server#3997
  * Implement retry handling for failed Elasticsearch requests. Graylog2/graylog2-server#4012 Graylog2/graylog2-server#3993
  * Fix NullPointerException in ExceptionUtils. Graylog2/graylog2-server#4014 Graylog2/graylog2-server#4003
  * Avoid noisy stack traces when Elasticsearch is not available. Graylog2/graylog2-server#3934 Graylog2/graylog2-server#3861
  * Do not run SetIndexReadOnlyAndCalculateRangeJob if index is closed. Graylog2/graylog2-server#3931 Graylog2/graylog2-server#3909
  * Fix issues when updating users and user roles. Graylog2/graylog2-server#3942 Graylog2/graylog2-server#3918
  * Improved IPv6 support. Graylog2/graylog2-server#3926 Graylog2/graylog2-server#3870
  * Fix login code to unbreak SSO plugin. Graylog2/graylog2-server#3973 Graylog2/graylog2-server#3948
  * Allow case-insensitive lookups for CSV lookup data adapter. Graylog2/graylog2-server#3971 Graylog2/graylog2-server#3961
  * Allow manual lookup table cache purge via UI and API. Graylog2/graylog2-server#3967 Graylog2/graylog2-server#3962
  * Mark Message class as not thread-safe. Graylog2/graylog2-server#3978 Graylog2/graylog2-server#3876
  * Fail fast and loud for invalid GELF messages. Graylog2/graylog2-server#3972 Graylog2/graylog2-server#3970
  * Add support for automatic Elasticsearch node discovery. Graylog2/graylog2-server#3805
  * Fix DateHistogram-related functionality in Searches class. Graylog2/graylog2-server#3806
  * Hide update spinner with auto-update interval <=5s. Graylog2/graylog2-server#3738 Graylog2/graylog2-server#3723 @billmurrin
  * Small spelling/documentation fixes. Graylog2/graylog2-server#3817
  * Fix pagination and offset/total hits in Searches. Graylog2/graylog2-server#3821 Graylog2/graylog2-server#3813
  * Add sort order to terms API call. Graylog2/graylog2-server#3829
  * Don’t start stopped inputs after updating them. Graylog2/graylog2-server#3824 Graylog2/graylog2-server#3479
  * Allow specifying locale for Date converter. Graylog2/graylog2-server#3820
  * Hide “Delete from stream” button if stream is undefined. Graylog2/graylog2-server#3822
  * Don’t reload errorstates on pages that don’t need them. Graylog2/graylog2-server#3839 Graylog2/graylog2-server#3834
  * Emit StreamsChangedEvent and StreamDeletedEvent in BundleImporter. Graylog2/graylog2-server#3848 Graylog2/graylog2-server#3842
  * Add Lookup Table search result decorator. Graylog2/graylog2-server#3852 Graylog2/graylog2-server#3844
  * Check Elasticsearch version when creating index template. Graylog2/graylog2-server#3862
  * Add admin user to list of receivers in EmailAlarmCallback. Graylog2/graylog2-server#3864 Graylog2/graylog2-server#3859
  * Fix parameters for count query in Searches#count(). Graylog2/graylog2-server#3865 Graylog2/graylog2-server#3841
  * Add search system for objects in MongoDB Graylog2/graylog2-server#3877
  * Make Kafka config setting auto.offset.reset configurable for input. Graylog2/graylog2-server#3743 Graylog2/graylog2-server#3894 @r4um
  * Use preemptive authentication for Elasticsearch if credentials are given. Graylog2/graylog2-server#3895 Graylog2/graylog2-server#3907
  * Add lookup adapter and cache config validation. Graylog2/graylog2-server#3836
  * Unbreak elasticsearch duration config settings. Graylog2/graylog2-server#3899
  * Fix lookup table UI state problem. Graylog2/graylog2-server#3898
  * Enable search for lookup tables, data adapters and caches. Graylog2/graylog2-server#3878
  * Make Elasticsearch version injectable. Graylog2/graylog2-server#3896
  * Refactor lifecycle for lookup adapters and caches. Graylog2/graylog2-server#3873
  * Introduce setting for enabling ES request compression. Graylog2/graylog2-server#3901
  * Add content pack import/export for lookup tables, caches and adapters. Graylog2/graylog2-server#3892
  * Upgrade to Jackson 2.8.9. Graylog2/graylog2-server#3908
  * Fix and centralize lookup adapter/cache error handling. Graylog2/graylog2-server#3905
  * Switch RoleResponse to java.util.Optional to fix serialization. Graylog2/graylog2-server#3915
  * Add lookup table/cache/adapter permissions. Graylog2/graylog2-server#3914
  * Collect and show metrics for lookup caches and adapters. Graylog2/graylog2-server#3917
  * Remove obsolete “disableExpensiveUpdates” user preference. Graylog2/graylog2-server#3922
  * Migrate to Jackson-based release of Jest 2.4.5. Graylog2/graylog2-server#3925
  * Use aliases for reopened indices. Graylog2/graylog2-server#3897
  * Add default values for lookup tables. Graylog2/graylog2-server#3921
  * Add support for updating extractors in InputService. Graylog2/graylog2-server#3910
  * Fix index set overview with closed indices. Graylog2/graylog2-server#3930
  * Don’t check ES cluster health when flushing messages. Graylog2/graylog2-server#3927
  * Retrying bulk indexing in case of all IOExceptions. Graylog2/graylog2-server#3929 Graylog2/graylog2-server#3941
  * Add support for automatic Elasticsearch node discovery. Graylog2/graylog2-server#3805
  * Fix DateHistogram-related functionality in Searches class. Graylog2/graylog2-server#3806
  * Hide update spinner with auto-update interval <=5s. Graylog2/graylog2-server#3738 Graylog2/graylog2-server#3723 @billmurrin
  * Small spelling/documentation fixes. Graylog2/graylog2-server#3817
  * Fix pagination and offset/total hits in Searches. Graylog2/graylog2-server#3821 Graylog2/graylog2-server#3813
  * Add timing metrics to GelfOutput. Graylog2/graylog2-server#3810 Graylog2/graylog2-server#3716
  * Add sort order to terms API call. Graylog2/graylog2-server#3829
  * Don’t start stopped inputs after updating them. Graylog2/graylog2-server#3824 Graylog2/graylog2-server#3479
  * Allow specifying locale for Date converter. Graylog2/graylog2-server#3820
  * Hide “Delete from stream” button if stream is undefined. Graylog2/graylog2-server#3822
  * Don’t reload errorstates on pages that don’t need them. Graylog2/graylog2-server#3839 Graylog2/graylog2-server#3834
  * Emit StreamsChangedEvent and StreamDeletedEvent in BundleImporter. Graylog2/graylog2-server#3848 Graylog2/graylog2-server#3842
  * Add Lookup Table search result decorator. Graylog2/graylog2-server#3852 Graylog2/graylog2-server#3844
  * Check Elasticsearch version when creating index template. Graylog2/graylog2-server#3862
  * Add admin user to list of receivers in EmailAlarmCallback. Graylog2/graylog2-server#3864 Graylog2/graylog2-server#3859
  * Fix parameters for count query in Searches#count(). Graylog2/graylog2-server#3865 Graylog2/graylog2-server#3841
  * Allow version ‘0’ for structured syslog messages. Graylog2/graylog2-server#3503
  * Ignore Content-Type in HttpTransport. Graylog2/graylog2-server#3508 Graylog2/graylog2-server#3477
  * Ensure that index_prefix is lower case. Graylog2/graylog2-server#3509 Graylog2/graylog2-server#3476
  * Make map in MessageInput#asMap() mutable. Graylog2/graylog2-server#3521 Graylog2/graylog2-server#3515
  * Fix pagination for alert conditions. Graylog2/graylog2-server#3529 Graylog2/graylog2-server#3528
  * Wait until alert notification types are loaded. Graylog2/graylog2-server#3537 Graylog2/graylog2-server#3534
  * Upgrade development environment to Webpack v2. Graylog2/graylog2-server#3460
  * Add an option to repeat alert notifications again. Graylog2/graylog2-server#3536 Graylog2/graylog2-server#3511
  * Fix accidentally changed exports of UsersStore Graylog2/graylog2-server#3560 Graylog2/graylog2-server#3556
  * Properly escape username/roles in web interface. Graylog2/graylog2-server#3570 Graylog2/graylog2-server#3569
  * Improved dashboard grid system. Graylog2/graylog2-server#3575
  * Add support for sorting by count to Search#terms(). Graylog2/graylog2-server#3540 (@billmurrin)
  * Fix for copy query button. Graylog2/graylog2-server#3548 (@billmurrin)
  * Fix issue with cloning streams. Graylog2/graylog2-server#3615 Graylog2/graylog2-server#3608
  * Prevent session extension when polling system messages. Graylog2/graylog2-server#3632 Graylog2/graylog2-server#3628
  * Prevent session extension when polling system jobs. Graylog2/graylog2-server#3625 Graylog2/graylog2-server#3587
  * Prevent NPE due to race between rotation and retention threads. Graylog2/graylog2-server#3637 Graylog2/graylog2-server#3494
  * Fix problem with message decorators and field selection. Graylog2/graylog2-server#3585 Graylog2/graylog2-server#3584
  * Fix issue with loading indicator on an empty search result page. Graylog2/graylog2-server#3652 Graylog2/graylog2-server#3650
  * Fix navigation in LDAP users UI. Graylog2/graylog2-server#3651 Graylog2/graylog2-server#3485
  * Ensure that plugin RPMs will be built for Linux. Graylog2/graylog2-server#3658 Graylog2/graylog2-server#3657
  * Fix reloading problem with content packs and GROK patterns. Graylog2/graylog2-server#3621 Graylog2/graylog2-server#3610
  * Add support for Cisco and FortiGate Syslog messages. Graylog2/graylog2-server#3599
  * Fix permission problem for inputs API. Graylog2/graylog2-server#3681
  * Restore removal of role permissions upon roles update. Graylog2/graylog2-server#3683
  * Comply with grace condition when repeat alert notifications is enabled. Graylog2/graylog2-server#3676 Graylog2/graylog2-server#3579
  * Invalidate dashboards data after logout. Graylog2/graylog2-server#3700 Graylog2/graylog2-server#3693
  * Fix OptionalStringValidator and validations for extractors. Graylog2/graylog2-server#3633 Graylog2/graylog2-server#3630
  * Better time range for “Show Received Messages” button on inputs page. Graylog2/graylog2-server#3725
  * Remove deprecated rotation/retention configuration resources. Graylog2/graylog2-server#3724
  * Introduce lookup tables feature. Graylog2/graylog2-server#3748
  * Creating dashboard from search page does now select the right ID Graylog2/graylog2-server#3786 Graylog2/graylog2-server#3785
  * Fix importing of dashboards from content packs Graylog2/graylog2-server#3766 Graylog2/graylog2-server#3765
  + Beats Plugin
  * Spelling fixes. Graylog2/graylog-plugin-beats#22 @jsoref
  + Collector Plugin
  * Increase “Show messages” time range.
  * Allow collectors list to be filtered by tags. Graylog2/graylog-plugin-collector#52
  * UI and UX improvements. Graylog2/graylog-plugin-collector#55
  * Fix configuration setting usage for collector heartbeat interval. Graylog2/graylog-plugin-collector#58
  * Prevent unwanted session extension. Graylog2/graylog-plugin-collector#49
  + Map Widget Plugin
  * Adjust to lookup cache and adapter changes in server. Graylog2/graylog-plugin-map-widget#48 Graylog2/graylog-plugin-map-widget#50
  * Fix refresh handling in error conditions. Graylog2/graylog-plugin-map-widget#49
  * Fix HMR as in Graylog/graylog2-server#3591 Graylog2/graylog-plugin-map-widget#51
  * Update to a new GeoIP2 release.
  * Add lookup tables data adapter for the GeoIP2 database. Graylog2/graylog-plugin-map-widget#40
  + Pipeline Processor Plugin
  * Improve robustness of clone_message() pipeline function. Graylog2/graylog-plugin-pipeline-processor#192 Graylog2/graylog2-server#3880
  * Fix pipline condition handling of “match all”/”match either”. Graylog2/graylog-plugin-pipeline-processor#193 Graylog2/graylog2-server#3924
  * Fix serialization/deserialization of pipeline StageSource. Graylog2/graylog-plugin-pipeline-processor#195 Graylog2/graylog-plugin-pipeline-processor#194
  * Improve error handling with invalid expressions. Graylog2/graylog-plugin-pipeline-processor#196 Graylog2/graylog-plugin-pipeline-processor#185
  * Spelling fixes. Graylog2/graylog-plugin-pipeline-processor#181 @jsoref
  * Add support for custom locale in parse_date() function. Graylog2/graylog-plugin-pipeline-processor#184 Graylog2/graylog-plugin-pipeline-processor#183
  * Smaller UI and UX changes. Graylog2/graylog-plugin-pipeline-processor#186
  * New function: debug() Graylog2/graylog-plugin-pipeline-processor#188
  * Allow snake-case access to bean objects Graylog2/graylog-plugin-pipeline-processor#189
  * Improve lookup functions. Graylog2/graylog-plugin-pipeline-processor#191
  * Spelling fixes. Graylog2/graylog-plugin-pipeline-processor#181 @jsoref
  * Use uppercase timezone in TimezoneAwareFunction and fix default value. Graylog2/graylog2-server#169 Graylog2/graylog2-server#168
  * Add lookup and lookup_value pipeline functions for lookup table support. Graylog2/graylog2-server#177
* Tue May  9 2017 zombah@gmail.com
- add fillup_prereq
* Fri May  5 2017 zombah@gmail.com
- revert post fillup_and_insserv otherwise enviroment file is absent
* Thu Apr 20 2017 zombah@gmail.com
- move post fillup_and_insserv to non systemd condition
* Thu Apr 20 2017 zombah@gmail.com
- fix tumbleweed build with systemd conditions
* Wed Apr 19 2017 zombah@gmail.com
- update to 2.2.3
  + Core
  * Prevent unwanted session extension. Graylog2/graylog2-server#3583
  * Properly escape username/roles in web interface. Graylog2/graylog2-server#3588
  * Allow “-” in the path pattern for the index range rebuild endpoint. Graylog2/graylog2-server#3600
  * Copy Query Button Fix. Graylog2/graylog2-server#3491
  * Fixing slicing of alert notifications in pagination. Graylog2/graylog2-server#3619
  * Fix cloning alert conditions with identical id when cloning stream. Graylog2/graylog2-server#3616
  * Use UTC for embedded Date objects as well. Graylog2/graylog2-server#3626
  * Prevent session extension for polling system messages. Graylog2/graylog2-server#3638
  * Support replacing whitespace in nested keys for JSON extractor. Graylog2/graylog2-server#3623
  * Prevent NPE due to race between rotation and retention threads. Graylog2/graylog2-server#3640
  * Prevent session extension in SystemJobsStore. Graylog2/graylog2-server#3625
  * Render loading indicator on no results page. Graylog2/graylog2-server#3667
  * Using consistent collection of non displayable fields to filter against. Graylog2/graylog2-server#3668
  * Ensure that plugin RPMs will be built for Linux. Graylog2/graylog2-server#3659
  * Fix navigation in LDAP components. Graylog2/graylog2-server#3670
  * Publish GrokPatternsChangedEvent when using content packs. Graylog2/graylog2-server#3621
  * Add support for Cisco and FortiGate syslog messages. Graylog2/graylog2-server#3599
  * Effectively change user permissions when listing inputs. Graylog2/graylog2-server#3682
  * Restore removal of role permissions upon roles update. Graylog2/graylog2-server#3684
  * Comply with grace condition when repeat alert notifications is enabled Graylog2/graylog2-server#3676
  + Pipeline Processor
  * Use uppercase timezone in TimezoneAwareFunction and fix default value. Graylog2/graylog-plugin-pipeline-processor#169
* Tue Apr 18 2017 zombah@gmail.com
- Graylog2 only support elasticsearch 2.x, indicate it with correct require
* Mon Oct 24 2016 kkaempf@suse.com
- fix SLE11 build: disable empty subpackages
* Fri Sep 23 2016 darin@darins.net
- update to 2.1.1
  + Core
  * Proxied requests query other nodes in parallel. Graylog2/graylog2-server#2764, Graylog2/graylog2-server#2779
  * Fix 404s on IE 11 using compatibility view. Graylog2/graylog2-server#2768, Graylog2/graylog2-server#2782
  * Modify actions in search page triggering a page reload. Graylog2/graylog2-server#2488, Graylog2/graylog2-server#2798
  * Do not display login form while loading. Graylog2/graylog2-server#2770, Graylog2/graylog2-server#2802
  * Check in SearchPage if search is in progress, reuse promise then. Graylog2/graylog2-server#2799, Graylog2/graylog2-server#2803
  * Use index and message_id as message identifier. Graylog2/graylog2-server#2801, Graylog2/graylog2-server#2804
  * Fix: file handle leak in KeyUtil (SSL). Graylog2/graylog2-server#2808. Thank you @gbu-censhare!
  * Use current search time configuration for CSV export. Graylog2/graylog2-server#2795, Graylog2/graylog2-server#2809
  * Explicitly close okhttp response body, avoiding leak connection warning. Graylog2/graylog2-server#2811. Thank you @chainkite!
  * Properly close OkHttp Response objects to avoid resource leaks. Graylog2/graylog2-server#2812
  * Remove ldap settings check from authenticators. Graylog2/graylog2-server#2817, Graylog2/graylog2-server#2820
  + Map plugin
  * Ignore internal message fields (starting with "gl2_"). Graylog2/graylog-plugin-map-widget#17
  + Pipeline processor plugin
  * Display boolean values in pipeline simulator. Graylog2/graylog-plugin-pipeline-processor#54, Graylog2/graylog-plugin-pipeline-processor#99
  * Use case insensitive lookup for timezone IDs. Graylog2/graylog-plugin-pipeline-processor#100, Graylog2/graylog-plugin-pipeline-processor#102
* Tue Jun 21 2016 darin@darins.net
- update to 2.0.3
  Improvements
  + Server
  * Make Message#getStreamIds() more reliable Graylog2/graylog2-server#2378
  * Disabling a configured proxy for requests to localhost/127.0.0.1/::1. Graylog2/graylog2-server#2305
  Bug fixes
  + Server
  * Update search query on auto refresh Graylog2/graylog2-server#2385 Graylog2/graylog2-server#2379
  * Fix permission checks for non admin users Graylog2/graylog2-server#2366 Graylog2/graylog2-server#2358
  * Fix display of total count of indices. Graylog2/graylog2-server#2365 Graylog2/graylog2-server#2359
  * Fix base URI for API documentation Graylog2/graylog2-server#2362 Graylog2/graylog2-server#2360
  * Fix link to API Browser on Node pages Graylog2/graylog2-server#2361 Graylog2/graylog2-server#2360
  * Calculate keyword from and to values on the fly Graylog2/graylog2-server#2335 Graylog2/graylog2-server#2301
  * Make MemoryAppender thread-safe Graylog2/graylog2-server#2307 Graylog2/graylog2-server#2302
  * Use right metrics to display buffer usage Graylog2/graylog2-server#2300 Graylog2/graylog2-server#2299
  * Check if props actually contain configuration fields before copying them Graylog2/graylog2-server#2298 Graylog2/graylog2-server#2297
* Wed Jun 15 2016 darin@darins.net
- fix required versions for mongo and es
* Fri Jun  3 2016 darin@darins.net
- update the packaging to include stub packages for MongoDB and
  Elasticsearch
* Fri Jun  3 2016 darin@darins.net
- update to 2.0.2
  Improvements:
  + Server
  * Improved user form. Graylog2/graylog2-server#2261
  * Improved logging of plugin list on server startup. Graylog2/graylog2-server#2290
  * Forbid empty passwords when using LDAP. Graylog2/graylog2-server#2214 Graylog2/graylog2-server#2283
  * Improved metrics page. Graylog2/graylog2-server#2250 Graylog2/graylog2-server#2255
  * Improved search histogram resolution auto selection. Graylog2/graylog2-server#2148 Graylog2/graylog2-server#2289
  * Improved cluster overview page. Graylog2/graylog2-server#2291
  + Plugin: Pipeline Processor
  * Add syslog related rule functions. Graylog2/graylog-plugin-pipeline-processor#19
  * Add concat rule functions. Graylog2/graylog-plugin-pipeline-processor#20
  Bug fixes:
  + Server
  * Fixed concurrency issue with Drools. Graylog2/graylog2-server#2119 Graylog2/graylog2-server#2188 Graylog2/graylog2-server#2231
  * Fixed problems with Internet Explorer. Graylog2/graylog2-server#2246
  * Fixed issues with old dashboards. Graylog2/graylog2-server#2262 Graylog2/graylog2-server#2163
  * Fixed changing log levels via REST API. Graylog2/graylog2-server#1904 Graylog2/graylog2-server#2277
  * Fixed plugin inter-dependencies by using one class loader for all plugins. Graylog2/graylog2-server#2280
  + Plugin: Pipeline Processor
  * Fixed problem with IP address function. Graylog2/graylog-plugin-pipeline-processor#28 Graylog2/graylog-plugin-pipeline-processor#32
  * Properly unescape strings in raw literals. Graylog2/graylog-plugin-pipeline-processor#30 Graylog2/graylog-plugin-pipeline-processor#31
- cleanup and fixup spec file
* Mon Apr 18 2016 boris@steki.net
- updated to release 1.3.4
  + this is security releated update, upgrade is recommended
* Tue Dec 22 2015 boris@steki.net
- updated to version 1.3.2
  - Deserializing a blacklist filter leads to StackOverflowError
    Graylog2/graylog2-server#1641
- bugfix release
* Fri Dec 18 2015 darin@darins.net
- update to version 1.3.1
  + Add option to AMQP transports to bind the queue to the exchange
  +Install a Graylog index template instead of set mappings on index creation
* Wed Dec  9 2015 boris@steki.net
- updated to latest version 1.3.0
  + Allow index range calculation for a single index.
  +  Performance improvements for index ranges.
  +  Make internal server logs accessible via REST API.
  +  Make specific configuration values accessible via REST API.
  +  Added Replace Extractor.
  +  Added a default set of Grok patterns.
  +  Log operating system details on server startup.
  +  Allow reader users to set a dashboard as start page.
  +  Auto content pack loader - download and install content packs automatically
  +  Appliance pre-configured for log ingestion and analysis
  +  Show a getting started guide on first install.
- bugfixes:
  + Include role permissions in “/roles/{rolename}/members” REST API endpoint.
  +  Fixed NullPointerException in GELF output.
  +  Fixed NullPointerException in GELF input handling.
  +  Use the root user’s timezone for LDAP users by default.
  +  Fix display of JSON messages.
  +  Improve search robustness with missing Elasticsearch indices.
  +  Fixed race condition between index creation and index mapping configuration.
  +  Fixed concurrency problem in GELF input handling.
  +  Fixed issue with widget value calculation.
  +  Do not extend user sessions when updating widgets.
  +  Fixed compatibility mode for Internet Explorer.
  +  Fixed whitespace issue in extractor example.
  +  Fixed several issues on the indices page.
  +  Fixed permission issue for stream alert management.
  +  Fixed deletion of LDAP group mappings when updating LDAP settings.
  +  Fixed dangling role references after deleting a role
  +  Support LDAP Group Mapping for Sun Directory Server (new since beta.2)
* Tue Nov 17 2015 boris@steki.net
- updated to latest version 1.2.2
- mostly bugfix release
  - reversed decision to move metadata info to mongodb
- added Wants= and After= mongodb.service to make loading of graylog
  deterministic and not to fail when mongo is still not in running state
* Wed Oct 21 2015 boris@steki.net
- fix handling of exit code in systemd service file
* Tue Sep 29 2015 boris@steki.net
- updated to latest version 1.2.1
- Bug Fixes
  * Fixed various issues around importing and applying content packs
  * Fixed loading existing alarm callbacks that had been created with Graylog 1.0.x or earlier
  * Fixed compatibility problem with Elasticsearch 1.5.x and earlier
  * Fixed handling of statistical functions in field graphs
  * Use correct title when adding quick values to a dashboard
* Mon Sep 21 2015 boris@steki.net
- updated to version 1.2.0 from 1.1.6
  * User Roles & LDAP Group Support
  * Faster Stream Router Engine
  * OR Rule Stream Support
  * Improved Graylog Service Availability: Graylog server can
    now start without Elasticsearch
  * Stacked chart widget support
  * Cardinality Field Statistics
  * Alarm Callback History
  * Simplified Grok import/export with content pack support
  * Time zone support for date converter
  * Several Dashboard UI improvements
  * New Raw AMQP input
  * New Syslog AMQP input
  * TLS client certificate authentication to all TCP based inputs
  * TLS support for GELF HTTP input/output
  * New MessageListCodec interface
  * Keepalive configuration option for all TCP transports
  * New JSON field extractor
* Fri Aug 21 2015 boris@steki.net
- updated to version 1.1.6 from 1.1.4
  * Fix edge case in SyslogOctetCountFrameDecoder which caused the
    Syslog TCP input to reset connections (#1105, #1339)
  * Properly log errors in the Netty channel pipeline (#1340)
  * Prevent creation of invalid alert conditions (#1332)
  * Upgrade to Elasticsearch 1.6.2
  * Improve handling of exceptions in the JournallingMessageHandler (#1286)
  * Upgrade to Elasticsearch 1.6.1 (#1312)
  * Remove hard-coded limit for UDP receive buffer size (#1290)
  * Ensure that elasticsearch_index_prefix is lowercase (commit 2173225)
  * Add configuration option for time zone to Date converter (#1320)
  * Fix NPE if the disk journal is disabled on a node (#1520)
  * Statistic and Chart error: Adding time zone offset caused overflow (#1257)
  * Ignore stream alerts and throughput on serialize (#1309)
  * Fix dynamic keyword time-ranges for dashboard widgets
    created from content packs (#1308)
  * Upgraded Anonymous Usage Statistics plugin to version 1.1.1
* Fri Jul 17 2015 boris@steki.net
- updated to version 1.1.4
  * security release concearning  elasticsearch
* Mon Jun 22 2015 boris@steki.net
- updated to version 1.1.3
  * User interface updates
  * Integrated Log Collector
  * Server Enhancements
  * * for more info please go to:
    https://www.graylog.org/graylog-1-1-is-now-generally-available/
    https://www.graylog.org/graylog-v1-1-2-is-now-available/
    https://www.graylog.org/graylog-v1-1-3-is-now-available/
* Tue May  5 2015 boris@steki.net
- initial packaging of graylog version 1.0.2
